@@ -494,7 +494,7 @@ async def test_build_command(vm, fake_qemu_binary):
             "-m",
             "256M",
             "-smp",
-            "cpus=1",
+            "cpus=1,sockets=1",
             "-boot",
             "order=c",
             "-uuid",
@@ -544,7 +544,7 @@ async def test_build_command_kvm(linux_platform, vm, fake_qemu_binary):
                 "-m",
                 "256M",
                 "-smp",
-                "cpus=1",
+                "cpus=1,sockets=1",
                 "-enable-kvm",
                 "-boot",
                 "order=c",
@@ -580,7 +580,7 @@ async def test_build_command_kvm_2_4(linux_platform, vm, fake_qemu_binary):
                 "-m",
                 "256M",
                 "-smp",
-                "cpus=1",
+                "cpus=1,sockets=1",
                 "-enable-kvm",
                 "-machine",
                 "smm=off",
@@ -626,7 +626,7 @@ async def test_build_command_two_adapters(vm, fake_qemu_binary):
             "-m",
             "256M",
             "-smp",
-            "cpus=1",
+            "cpus=1,sockets=1",
             "-boot",
             "order=c",
             "-uuid",
